@@ -5,15 +5,15 @@ import re
 import warnings
 
 from   .calendar import (
-    load_calendar_file, load_business_calendar, CalendarDir, 
+    load_calendar_file, load_business_calendar, CalendarDir,
     format_calendar, dump_calendar_file,
-    get_calendar_dir, set_calendar_dir, get_calendar, 
+    get_calendar_dir, set_calendar_dir, get_calendar,
 )
 from   .ext import *
 from   .weekday import *
 from   .util import Range
 
-__version__ = "0.5.0"
+__version__ = "0.6.0"
 
 __all__ = (
     "Calendar",
@@ -53,6 +53,7 @@ __all__ = (
     "get_system_time_zone",
     "get_zoneinfo_dir",
     "is_leap_year",
+    "list_zoneinfo_dir",
     "make_const_calendar",
     "make_weekday_calendar",
     "now",
@@ -82,7 +83,7 @@ __all__ = (
 
     "Mon", "Tue", "Wed", "Thu", "Fri", "Sat", "Sun",
 
-    "Jan", "Feb", "Mar", "Apr", "May", "Jun", 
+    "Jan", "Feb", "Mar", "Apr", "May", "Jun",
     "Jul", "Aug", "Sep", "Oct", "Nov", "Dec",
 
     "display_time_zone",
@@ -100,20 +101,20 @@ TIME_TYPES = frozenset((
     Unix32Time,
     Unix64Time,
 ))
-    
+
 DATE_TYPES = frozenset((
     Date,
     Date16,
 ))
-    
+
 DAYTIME_TYPES = frozenset((
-    Daytime, 
-    Daytime32, 
+    Daytime,
+    Daytime32,
     UsecDaytime,
 ))
-    
 
-# Set the location of the time zone database.  If ZONEINFO is set in the 
+
+# Set the location of the time zone database.  If ZONEINFO is set in the
 # environment, use it; otherwise, use our own copy of the database.
 _INTERNAL_ZONEINFO_DIR = Path(__file__).parent / "zoneinfo"
 try:
@@ -279,3 +280,20 @@ def get_zoneinfo_version():
         return version
 
 
+def list_zoneinfo_dir(path=None):
+    """
+    Lists time zones in a zoneinfo directory.
+
+    :param path:
+      Zoneinfo directory.  If none, uses `get_zoneinfo_dir()`.
+    :return:
+      Iterable of time zone names.
+    """
+    root = Path(get_zoneinfo_dir() if path is None else path)
+    for dir, _, names in os.walk(root):
+        parts = Path(dir).relative_to(root).parts
+        for name in names:
+            if "." in name or name in ("leapseconds", "+VERSION"):
+                # These are other data files, not zoneinfo entries.
+                continue
+            yield "/".join((*parts, name))
